@@ -32,6 +32,8 @@ def _season_type_from_name(name: str) -> SeasonType:
         or "2012-2013 Barclays Premier League" in name
         or "2011-2012 Barclays Premier League" in name
         or "2010-2011 Barclays Premier League" in name
+        or "2009-2010 Barclays Premier League" in name
+        or "2008-2009 Barclays Premier League" in name
     ):
         return SeasonType.REGULAR
     if name == "Preseason" or "Spring Training" in name:
@@ -87,14 +89,22 @@ class ESPNLeagueModel(LeagueModel):
         season_type_json: dict[str, Any],
         pbar: tqdm.tqdm,
     ) -> Iterator[GameModel]:
-        if cache_disabled:
-            with self.session.cache_disabled():
+        event = event_item
+        if "$ref" in event_item:
+            if cache_disabled:
+                with self.session.cache_disabled():
+                    event_response = self.session.get(event_item["$ref"])
+            else:
                 event_response = self.session.get(event_item["$ref"])
-        else:
-            event_response = self.session.get(event_item["$ref"])
-        event_response.raise_for_status()
-        event = event_response.json()
-        for competition in event["competitions"]:
+            event_response.raise_for_status()
+            event = event_response.json()
+
+        competitions = event.get("competitions", [])
+        if not competitions:
+            for grouping in event.get("groupings", []):
+                competitions.extend(grouping["competitions"])
+
+        for competition in competitions:
             game_model = create_espn_game_model(
                 competition,
                 week_count,
@@ -241,7 +251,14 @@ class ESPNLeagueModel(LeagueModel):
                             }
                             calendar_dates &= declared_calendar_dates
                     for event in scoreboard["events"]:
-                        event_id = event["id"]
+                        if not event:
+                            continue
+                        try:
+                            event_id = event["id"]
+                        except KeyError as exc:
+                            logging.error(str(exc))
+                            logging.error(event)
+                            raise exc
                         event_response = self.session.get(
                             f"https://sports.core.api.espn.com/v2/sports/{sport_slug}/leagues/{league_slug}/events/{event_id}?lang=en&region=us"
                         )
@@ -256,7 +273,7 @@ class ESPNLeagueModel(LeagueModel):
                         ):
                             yield game_model
                             events_count += 1
-                except (requests.exceptions.JSONDecodeError, KeyError) as exc:
+                except requests.exceptions.JSONDecodeError as exc:
                     logging.error(scoreboard_response.text)
                     logging.error(url)
                     logging.error(str(exc))
