@@ -8,6 +8,7 @@ class League(StrEnum):
     """An enumeration over the different leagues."""
 
     AFL = "afl"
+    AFLW = "aflw"
     ATP = "atp"
     EPL = "epl"
     FIFA = "fifa"
@@ -20,6 +21,7 @@ class League(StrEnum):
     NFL = "nfl"
     NHL = "nhl"
     WNBA = "wnba"
+    WTA = "wta"
 
 
 def long_name(league: League) -> str:
@@ -27,6 +29,8 @@ def long_name(league: League) -> str:
     match league:
         case League.AFL:
             return "Australia Football League"
+        case League.AFLW:
+            return "Australia Football League Womens"
         case League.ATP:
             return "Association of Tennis Professionals"
         case League.EPL:
@@ -51,6 +55,8 @@ def long_name(league: League) -> str:
             return "National Hockey League"
         case League.WNBA:
             return "Womens National Basketball League"
+        case League.WTA:
+            return "Womens Tennis Association"
 
 
 def league_from_str(league_str: str) -> League:
@@ -59,6 +65,8 @@ def league_from_str(league_str: str) -> League:
     match league_str:
         case str(League.AFL):
             return League.AFL
+        case str(League.AFLW):
+            return League.AFLW
         case str(League.ATP):
             return League.ATP
         case str(League.EPL):
@@ -83,5 +91,7 @@ def league_from_str(league_str: str) -> League:
             return League.NHL
         case str(League.WNBA):
             return League.WNBA
+        case str(League.WTA):
+            return League.WTA
         case _:
             raise ValueError(f"Unrecognised League: {league_str}")
