@@ -6,7 +6,6 @@ from ...combined.combined_league_model import CombinedLeagueModel
 from ...league import League
 from ..espn.mlb_espn_league_model import MLBESPNLeagueModel
 from ..oddsportal.mlb_oddsportal_league_model import MLBOddsPortalLeagueModel
-from ..sportsdb.mlb_sportsdb_league_model import MLBSportsDBLeagueModel
 
 MLB_TEAM_IDENTITY_MAP: dict[str, str] = {}
 MLB_VENUE_IDENTITY_MAP: dict[str, str] = {}
@@ -22,8 +21,8 @@ class MLBCombinedLeagueModel(CombinedLeagueModel):
             League.MLB,
             [
                 MLBESPNLeagueModel(session, position=0),
-                MLBSportsDBLeagueModel(session, position=1),
-                MLBOddsPortalLeagueModel(session, position=2),
+                MLBOddsPortalLeagueModel(session, position=1),
+                # MLBSportsDBLeagueModel(session, position=2),
                 # MLBSportsReferenceLeagueModel(session, position=3),
             ],
             league_filter,
